/*
 * Copyright (C) 2019-2024 CZ.NIC z.s.p.o. (https://www.nic.cz/)
 *
 * This is free software, licensed under the GNU General Public License v3.
 * See /LICENSE for more information.
 */

import React from "react";

import {
    fireEvent,
    getByText,
    queryByText,
    render,
    wait,
} from "customTestRender";
import mockAxios from "jest-mock-axios";
import { mockJSONError } from "testUtils/network";
import { mockSetAlert } from "testUtils/alertContextMock";

import ActionButtonWithModal from "../ActionButtonWithModal/ActionButtonWithModal";

describe("<ActionButtonWithModal/>", () => {
    let componentContainer;
    beforeEach(() => {
        const { container } = render(
            <>
                <div id="modal-container" />
                <div id="alert-container" />
                <ActionButtonWithModal />
            </>
        );
        componentContainer = container;
    });

    it("Render.", () => {
        expect(componentContainer).toMatchSnapshot();
    });

    it("Render modal.", () => {
        expect(queryByText(componentContainer, "Confirm action")).toBeNull();
        fireEvent.click(getByText(componentContainer, "Action"));
        expect(componentContainer).toMatchSnapshot();
    });

    it("Confirm action.", () => {
        fireEvent.click(getByText(componentContainer, "action"));
        fireEvent.click(getByText(componentContainer, "Confirm action"));
        expect(mockAxios.post).toHaveBeenCalledWith(
            "/reforis/api/action",
            undefined,
            expect.anything()
        );
    });

    it("Hold error.", async () => {
        fireEvent.click(getByText(componentContainer, "Action"));
        fireEvent.click(getByText(componentContainer, "Confirm action"));
        mockJSONError();
        await wait(() =>
            expect(mockSetAlert).toBeCalledWith("Action request failed.")
        );
    });
});
